/// <reference types="express" />
import type { Request as GcfRequest, Response as GcfResponse } from "@google-cloud/functions-framework";
import type { AppLoadContext, ServerBuild } from "@remix-run/node";
import { Headers as NodeHeaders, Request as NodeRequest } from "@remix-run/node";
/**
 * A function that returns the value to use as `context` in route `loader` and
 * `action` functions.
 *
 * You can think of this as an escape hatch that allows you to pass
 * environment/platform-specific values through to your loader/action.
 */
export interface GetLoadContextFunction {
    (req: GcfRequest, res: GcfResponse): AppLoadContext;
}
export type RequestHandler = (req: GcfRequest, res: GcfResponse) => Promise<void>;
/**
 * Returns a request handler for Google Cloud functions that serves the response using Remix.
 */
export declare function createRequestHandler({ build, getLoadContext, mode, }: {
    build: ServerBuild;
    getLoadContext?: GetLoadContextFunction;
    mode?: string;
}): RequestHandler;
export declare function createRemixHeaders(requestHeaders: GcfRequest["headers"]): NodeHeaders;
export declare function createRemixRequest(req: GcfRequest, res: GcfResponse): NodeRequest;
